==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_up() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return ChaikinVolatilityIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.vb));
        }
        set va(a) {
            this.h(ChaikinVolatilityIndicator.vb, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
    }
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.vb = StrategyBasedIndicator.u7(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return ChaikinVolatilityIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.zk));
        }
        set zj(a) {
            this.h(ChaikinVolatilityIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.zk = StrategyBasedIndicator.zg(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();
